# Translated to .py by Meritxell Pacheco (December 2016)

from biogeme import *
from headers import *
from loglikelihood import *
from statistics import *

# Parameters to be estimated
ASC_CAR	 = Beta('ASC_CAR',0,-10,10,0)
ASC_TRAIN	 = Beta('ASC_TRAIN',0,-10,10,1)
ASC_SM	 = Beta('ASC_SM',0,-10,10,0)
BETA_COST	 = Beta('BETA_COST',0,-1,1,0)
BETA_HE	 = Beta('BETA_HE',0,-1,1,0)
BETA_TIME	 = Beta('BETA_TIME',0,-1,1,0)

# Expressions
CAR_AV_SP  = DefineVariable('CAR_AV_SP', CAR_AV    *  (  SP   !=  0  ))
SM_COST  = DefineVariable('SM_COST', SM_CO   * (  GA   ==  0  ))
TRAIN_AV_SP  = DefineVariable('TRAIN_AV_SP', TRAIN_AV    *  (  SP   !=  0  ))
TRAIN_COST  = DefineVariable('TRAIN_COST', TRAIN_CO   * (  GA   ==  0  ))
one  = DefineVariable('one',1)

# Utilities
Car_SP = ASC_CAR * one + BETA_TIME * CAR_TT + BETA_COST * CAR_CO
TRAIN_SP = ASC_TRAIN * one + BETA_TIME * TRAIN_TT + BETA_COST * TRAIN_COST + BETA_HE * TRAIN_HE
SM_SP = ASC_SM * one + BETA_TIME * SM_TT + BETA_COST * SM_COST + BETA_HE * SM_HE
V = {3: Car_SP,1: TRAIN_SP,2: SM_SP}
av = {3: CAR_AV_SP,1: TRAIN_AV_SP,2: SM_AV}

# Choice model
l = bioLogLogit(V,av,CHOICE)

# Defines an iterator on the data
rowIterator('obsIter')

# Define the likelihood function for the estimation
BIOGEME_OBJECT.ESTIMATE = Sum(l,'obsIter')

# Exclude data
exclude = (( PURPOSE != 1 ) * (  PURPOSE   !=  3  ) + ( CHOICE == 0 )) > 0
BIOGEME_OBJECT.EXCLUDE = exclude

# Statistics
nullLoglikelihood(av,'obsIter')
choiceSet = [1,2,3]
cteLoglikelihood(choiceSet,CHOICE,'obsIter')
availabilityStatistics(av,'obsIter')

BIOGEME_OBJECT.PARAMETERS['optimizationAlgorithm'] = "BIO"
BIOGEME_OBJECT.PARAMETERS['stopFileName'] = "STOP"

BIOGEME_OBJECT.FORMULAS['Train utility'] = TRAIN_SP
BIOGEME_OBJECT.FORMULAS['Swissmetro utility'] = SM_SP
BIOGEME_OBJECT.FORMULAS['Car utility'] = Car_SP