# Translated to .py by Meritxell Pacheco (December 2016)

from biogeme import *
from headers import *
from nested import *
from loglikelihood import *
from statistics import *

# Parameters to be estimated
ASC_CAR	 = Beta('ASC_CAR',0,-10,10,0)
ASC_TRAIN	 = Beta('ASC_TRAIN',0,-10,10,1)
ASC_SM	 = Beta('ASC_SM',0,-10,10,0)
BETA_CAR_COST_mean	 = Beta('BETA_CAR_COST_mean',0,-10,10,0)
BETA_CAR_COST_std	 = Beta('BETA_CAR_COST_std',0,-10,10,0)
BETA_HE_mean	 = Beta('BETA_HE_mean',0,-10,10,0)
BETA_HE_std	 = Beta('BETA_HE_std',0,-10,10,0)
BETA_SM_COST_mean	 = Beta('BETA_SM_COST_mean',0,-10,10,0)
BETA_SM_COST_std	 = Beta('BETA_SM_COST_std',0,-10,10,0)
BETA_TIME	 = Beta('BETA_TIME',0,-10,10,0)
BETA_TRAIN_COST_mean	 = Beta('BETA_TRAIN_COST_mean',0,-10,10,0)
BETA_TRAIN_COST_std	 = Beta('BETA_TRAIN_COST_std',0,-10,10,0)
Existing = Beta('Existing',1,1,10, 0)
Innovative = Beta('Innovative',1,1,10,1)

#Random parameters
BETA_CAR_COST_random = BETA_CAR_COST_mean + BETA_CAR_COST_std * bioDraws('BETA_CAR_COST_random')
BETA_HE_random = BETA_HE_mean + BETA_HE_std * bioDraws('BETA_HE_random')
BETA_SM_COST_random = BETA_SM_COST_mean + BETA_SM_COST_std * bioDraws('BETA_SM_COST_random')
BETA_TRAIN_COST_random = BETA_TRAIN_COST_mean + BETA_TRAIN_COST_std * bioDraws('BETA_TRAIN_COST_random')

# Expressions
CAR_AV_SP  = DefineVariable('CAR_AV_SP', CAR_AV    *  (  SP   !=  0  ))
SM_COST  = DefineVariable('SM_COST', SM_CO   * (  GA   ==  0  ))
TRAIN_AV_SP  = DefineVariable('TRAIN_AV_SP', TRAIN_AV    *  (  SP   !=  0  ))
TRAIN_COST  = DefineVariable('TRAIN_COST', TRAIN_CO   * (  GA   ==  0  ))
one  = DefineVariable('one',1)

# Utilities
Car_SP = ASC_CAR * one + BETA_TIME * CAR_TT + BETA_CAR_COST_random * CAR_CO
TRAIN_SP = ASC_TRAIN * one + BETA_TIME * TRAIN_TT + BETA_TRAIN_COST_random * TRAIN_COST + BETA_HE_random * TRAIN_HE
SM_SP = ASC_SM * one + BETA_TIME * SM_TT + BETA_SM_COST_random * SM_COST + BETA_HE_random * SM_HE
V = {3: Car_SP,1: TRAIN_SP,2: SM_SP}
av = {3: CAR_AV_SP,1: TRAIN_AV_SP,2: SM_AV}

# Nests
Existing = Existing , [ 1,  3]
Innovative = Innovative , [ 2]
nests = Existing, Innovative

# Choice model
prob = nested(V,av,nests,CHOICE)
l = mixedloglikelihood(prob)

# Defines an iterator on the data
rowIterator('obsIter')

# Define the likelihood function for the estimation
BIOGEME_OBJECT.ESTIMATE = Sum(l,'obsIter')

# Exclude data
exclude = (( PURPOSE != 1 ) * (  PURPOSE   !=  3  ) + ( CHOICE == 0 )) > 0
BIOGEME_OBJECT.EXCLUDE = exclude

# Statistics
nullLoglikelihood(av,'obsIter')
choiceSet = [1,2,3]
cteLoglikelihood(choiceSet,CHOICE,'obsIter')
availabilityStatistics(av,'obsIter')

BIOGEME_OBJECT.PARAMETERS['NbrOfDraws'] = "50"

BIOGEME_OBJECT.PARAMETERS['optimizationAlgorithm'] = "CFSQP"
BIOGEME_OBJECT.DRAWS = {'BETA_CAR_COST_random': 'NORMAL', 'BETA_HE_random': 'NORMAL', 'BETA_SM_COST_random': 'NORMAL', 'BETA_TRAIN_COST_random': 'NORMAL'}

BIOGEME_OBJECT.FORMULAS['Train utility'] = TRAIN_SP
BIOGEME_OBJECT.FORMULAS['Swissmetro utility'] = SM_SP
BIOGEME_OBJECT.FORMULAS['Car utility'] = Car_SP